@@ -1,6 +1,5 @@
 package MooX::Emulate::Class::Accessor::Fast;
-
-$MooX::Emulate::Class::Accessor::Fast::VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
@@ -52,7 +51,6 @@ use Class::Method::Modifiers qw( install_modifier );
 use Carp qw( croak );
 
 use Moo::Role;
-use strictures 2;
 
 sub BUILD { }
 
